<?php
/**
 * Instagram Section options
 *
 * @package Theme Palace
 * @subpackage BlogSlog Pro
 * @since BlogSlog Pro 1.0.0
 */

// Add Instagram section
$wp_customize->add_section( 'blogslog_pro_instagram_section', array(
	'title'             => esc_html__( 'Instagram','blogslog-pro' ),
	'description'       => esc_html__( 'Instagram Section options.', 'blogslog-pro' ),
	'panel'             => 'blogslog_pro_front_page_panel',
) );

// Instagram content enable control and setting
$wp_customize->add_setting( 'blogslog_pro_theme_options[instagram_section_enable]', array(
	'default'			=> 	$options['instagram_section_enable'],
	'sanitize_callback' => 'blogslog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new BlogSlog_Pro_Switch_Control( $wp_customize, 'blogslog_pro_theme_options[instagram_section_enable]', array(
	'label'             => esc_html__( 'Instagram Section Enable', 'blogslog-pro' ),
	'section'           => 'blogslog_pro_instagram_section',
	'on_off_label' 		=> blogslog_pro_switch_options(),
) ) );

// instagram title setting and control
$wp_customize->add_setting( 'blogslog_pro_theme_options[instagram_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['instagram_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blogslog_pro_theme_options[instagram_title]', array(
	'label'           	=> esc_html__( 'Title', 'blogslog-pro' ),
	'section'        	=> 'blogslog_pro_instagram_section',
	'active_callback' 	=> 'blogslog_pro_is_instagram_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blogslog_pro_theme_options[instagram_title]', array(
		'selector'            => '#instagram-section .section-header h2.section-title',
		'settings'            => 'blogslog_pro_theme_options[instagram_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'blogslog_pro_instagram_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'blogslog_pro_theme_options[instagram_count]', array(
	'default'          	=> $options['instagram_count'],
	'sanitize_callback' => 'blogslog_pro_sanitize_number_range',
	'validate_callback' => 'blogslog_pro_validate_instagram_count',
) );

$wp_customize->add_control( 'blogslog_pro_theme_options[instagram_count]', array(
	'label'             => esc_html__( 'Number of Featured', 'blogslog-pro' ),
	'description'       => esc_html__( 'Note: Min 6 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'blogslog-pro' ),
	'section'           => 'blogslog_pro_instagram_section',
	'active_callback'   => 'blogslog_pro_is_instagram_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 6,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );