<?php
/**
 * List Articles section
 *
 * This is the template for the content of list articles section
 *
 * @package Theme Palace
 * @subpackage BlogSlog Pro
 * @since BlogSlog Pro 1.0.0
 */
if ( ! function_exists( 'blogslog_pro_add_list_articles_section' ) ) :
    /**
    * Add list articles section
    *
    *@since BlogSlog Pro 1.0.0
    */
    function blogslog_pro_add_list_articles_section() {
    	$options = blogslog_pro_get_theme_options();
        // Check if list articles is enabled on frontpage
        $list_articles_enable = apply_filters( 'blogslog_pro_section_status', true, 'list_articles_section_enable' );

        if ( true !== $list_articles_enable ) {
            return false;
        }
        // Get list articles section details
        $section_details = array();
        $section_details = apply_filters( 'blogslog_pro_filter_list_articles_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render list articles section now.
        blogslog_pro_render_list_articles_section( $section_details );
    }
endif;

if ( ! function_exists( 'blogslog_pro_get_list_articles_section_details' ) ) :
    /**
    * list articles section details.
    *
    * @since BlogSlog Pro 1.0.0
    * @param array $input list articles section details.
    */
    function blogslog_pro_get_list_articles_section_details( $input ) {
        $options = blogslog_pro_get_theme_options();

        // Content type.
        $list_articles_content_type  = $options['list_articles_content_type'];
        $list_articles_count = ! empty( $options['list_articles_count'] ) ? $options['list_articles_count'] : 4;
        
        $content = array();
        switch ( $list_articles_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $list_articles_count; $i++ ) {
                    if ( ! empty( $options['list_articles_content_page_' . $i] ) )
                        $page_ids[] = $options['list_articles_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $list_articles_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $list_articles_count; $i++ ) {
                    if ( ! empty( $options['list_articles_content_post_' . $i] ) )
                        $post_ids[] = $options['list_articles_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $list_articles_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['list_articles_content_category'] ) ? $options['list_articles_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $list_articles_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = blogslog_pro_trim_content( 25 );
                    $page_post['author']    = blogslog_pro_author();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// list articles section content details.
add_filter( 'blogslog_pro_filter_list_articles_section_details', 'blogslog_pro_get_list_articles_section_details' );


if ( ! function_exists( 'blogslog_pro_render_list_articles_section' ) ) :
  /**
   * Start list articles section
   *
   * @return string list articles content
   * @since BlogSlog Pro 1.0.0
   *
   */
   function blogslog_pro_render_list_articles_section( $content_details = array() ) {
        $options = blogslog_pro_get_theme_options();
        $list_articles_content_type = $options['list_articles_content_type'];
        $readmore = ! empty( $options['list_articles_readmore'] ) ? $options['list_articles_readmore'] : esc_html__( 'Continue Reading', 'blogslog-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="call-to-action" class="relative page-section blog-posts">
            <div class="wrapper">
                <?php foreach ( $content_details as $content ) : ?>
                    <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-featured-image">
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                        <div class="entry-container">
                            <?php if ( 'page' !== $list_articles_content_type ) : ?>
                                <span class="cat-links">
                                    <?php the_category( '', '', $content['id'] ); ?>
                                </span><!-- .cat-links -->
                            <?php endif; ?>

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <?php if ( 'page' !== $list_articles_content_type ) : ?>
                                <div class="entry-meta">
                                    <?php 
                                        blogslog_pro_posted_on( $content['id'] ); 
                                        echo wp_kses_post( $content['author'] );
                                    ?>  
                                </div><!-- .entry-meta -->
                            <?php endif; ?>

                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $readmore ); ?></a>
                            </div><!-- .read-more -->
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach; ?>
            </div><!-- .wrapper -->
            <div class="view-more">
                <button id="LBloadmore" class="btn"><?php echo esc_html__( 'Load More', 'blogslog-pro' ); ?></button>
            </div>
        </div><!-- #call-to-action -->

    <?php }
endif;