<?php
/**
 * Secondary Nav section
 *
 * This is the template for the content of secondary nav section
 *
 * @package Theme Palace
 * @subpackage BlogSlog Pro
 * @since BlogSlog Pro 1.0.0
 */
if ( ! function_exists( 'blogslog_pro_add_secondary_nav_section' ) ) :
    /**
    * Add secondary nav section
    *
    *@since BlogSlog Pro 1.0.0
    */
    function blogslog_pro_add_secondary_nav_section() {
        $options = blogslog_pro_get_theme_options();
        // Check if secondary nav is enabled on frontpage
        $secondary_nav_enable = apply_filters( 'blogslog_pro_section_status', true, 'secondary_nav_section_enable' );

        if ( true !== $secondary_nav_enable ) {
            return false;
        }

        // Render secondary nav section now.
        blogslog_pro_render_secondary_nav_section();
    }
endif;

if ( ! function_exists( 'blogslog_pro_render_secondary_nav_section' ) ) :
  /**
   * Start secondary nav section
   *
   * @return string secondary nav content
   * @since BlogSlog Pro 1.0.0
   *
   */
   function blogslog_pro_render_secondary_nav_section() {
        $options = blogslog_pro_get_theme_options();

        if ( ! has_nav_menu( 'secondary' ) ) {
            return;
        } 

        ?>
        <div id="secondary-navigation" class="relative">
            <div class="wrapper">
                <button class="menu-toggle" aria-controls="secondary-menu" aria-expanded="false">
                    <?php
                    echo blogslog_pro_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
                    echo blogslog_pro_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
                    ?>     
                    <span class="menu-label"><?php esc_html_e( 'Menu', 'blogslog-pro' ); ?></span>             
                </button>
                <nav id="page-navigation" class="main-navigation" role="navigation" aria-label="Secondary Menu">
                    <?php  

                    
                        wp_nav_menu( array(
                            'theme_location' => 'secondary',
                            'container' => false,
                            'menu_class' => 'menu nav-menu',
                            'menu_id' => 'secondary-menu',
                            'echo' => true,
                            'depth' => 1,
                            'fallback_cb' => 'blogslog_pro_menu_fallback_cb',
                        ) );
                    ?>
                </nav><!-- #site-navigation -->
            </div><!-- .wrapper -->
        </div><!-- #secondary-navigation -->
    <?php }
endif;